/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://eu-egee.org/partners/ for details on the copyright holders.
 * For license conditions see the license file or
 * http://eu-egee.org/license.html
 *
 * Copyright (c) 2004 by 
 *     David Groep <davidg@nikhef.nl>,
 *     Oscar Koeroo <okoeroo@nikhef.nl>,
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     Gerben Venekamp <venekamp@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 *     Universiteit van Amsterdam, the Netherlands
 */

/*!
    \file   lcmaps_verify_account_from_pem.h
    \brief  This interface verifies the  credential mapping from user
            credential in pem format.
    \author Martijn Steenbakkers for the EU DataGrid.

    \brief  This interface verifies the  credential mapping from user
            credential in pem format.
    As input it requires the user credential in PEM format and the lcmaps
    account from the type lcmaps_account_info_t.

    -# lcmaps_return_account_from_pem: interface function

    In general the behaviour of LCMAPS can be influenced by setting the following
    environment variables:
        Env variable                        Description
        (default value)
        ---------------                     -----------
        LCMAPS_LOG_FILE                     The logfile to which lcmaps log
        ("/var/log/lcmaps.log")             messages will be written

        LCMAPS_DB_FILE                      the location (name) of the lcmaps policy file
        (LCMAPS_ETC_DIR"/lcmaps.db")

        LCMAPS_POLICY_NAME                  the list of the lcmaps policies (in the
        ("acquisition_policy")              policy file) that should be evaluated until
                                            a policy succeeds. The policies are separated
                                            by ':', e.g. "policy_preferred:policy_fallback:".

        LCMAPS_LOG_STRING                   A string that will be prepended to all
        ("poolindex :")                     LCMAPS logging messages. If this variable is not
                                            set a default will be taken which includes a 
                                            timestamp

        LCMAPS_DEBUG_LEVEL                  The debug level influences the logging
        ("0")                               verbosity. values 0-5.

        LCMAPS_MODULES_DIR                  The directory in which modules can be found.
        ("")                                Note: may be overwritten by what is in
                                            the policy file (the convential method)

        LCMAPS_ETC_DIR                      The directory of the lcmaps policy files
        ("/opt/glite/etc/lcmaps")           and other config files. In this case this location
                                            is hardcoded to be "/opt/glite/etc/lcmaps", because this
                                            lcmaps interface is used by VO-services and, therefore, not
                                            controlled by the site.

        GRIDMAPDIR                          The directory in which the poolaccount leases
        ("")                                are registered.
                                            Note: may be overwritten by what is in
                                            the policy file (the convential method)

    \ingroup LcmapsInterface
*/

#ifndef LCMAPS_VERIFY_ACCOUNT_FROM_PEM_H
#define LCMAPS_VERIFY_ACCOUNT_FROM_PEM_H

#ifndef LCMAPS_VERIFY_ACCOUNT_FROM_PEM_C
#   define LCMAPS_VERIFY_ACCOUNT_FROM_PEM_C_STORAGE_CLASS extern
#else
#   define LCMAPS_VERIFY_ACCOUNT_FROM_PEM_C_STORAGE_CLASS
#endif

/******************************************************************************
                             Include header files
******************************************************************************/
#include "lcmaps_account.h"

/******************************************************************************
                   Module definition
 *****************************************************************************/

/******************************************************************************
Function:   lcmaps_verify_account_from_pem
Description:
    Verify the account mapping from the supplied user credential.
 
Parameters:
    pem_string:    :  The PEM-encoded string containing the user proxy
    lcmaps_account :  A structure that contains account information: (input)
                      uid, gids (primary and secondary).
                      Please use lcmaps_account_info_clean() to clean this
                      structure after use.
Returns:
    0: success
    1: failure
******************************************************************************/
/*!
    \fn lcmaps_verify_account_from_pem(
        char * pem_string,
        lcmaps_account_info_t lcmaps_account
    )

    \brief Verify the account mapping from the supplied user credential.

    \param pem_string
            The PEM-encoded string containing the user proxy
    \param lcmaps_account
            A structure that contains account information: (input)
            uid, gids (primary and secondary) and the poolindex
            Please use lcmaps_account_info_clean() to clean this
            structure after use.

    \retval 0 success.
    \retval 1 failure.
*/
LCMAPS_VERIFY_ACCOUNT_FROM_PEM_C_STORAGE_CLASS int
lcmaps_verify_account_from_pem(
        char * pem_string,
        lcmaps_account_info_t lcmaps_account
);

#endif /* LCMAPS_VERIFY_POOLINDEX_WITHOUT_GSI_H */
